pub struct StdClock { /* private fields */ }Expand description
A default Clock implementation when std is enabled.
When std is enabled, this is automatically utilized in TimedMap
to avoid requiring users to implement the Clock trait themselves.